#
# spec file for package texmath
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name texmath
%bcond_with tests
Name:           %{pkg_name}
Version:        0.12.3
Release:        1.1
Summary:        Conversion between formats used to represent mathematics
License:        GPL-2.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-xml-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-utf8-string-devel
%endif

%description
The texmath library provides functions to read and write TeX math, presentation
MathML, and OMML (Office Math Markup Language, used in Microsoft Office).
Support is also included for converting math formats to Gnu eqn and to pandoc's
native format (allowing conversion, via pandoc, to a variety of different
markup formats). The TeX reader supports basic LaTeX and AMS extensions, and it
can parse and apply LaTeX macros. (See <http://johnmacfarlane.net/texmath here>
for a live demo of bidirectional conversion between LaTeX and MathML.)

The package also includes several utility modules which may be useful for
anyone looking to manipulate either TeX math or MathML. For example, a copy of
the MathML operator dictionary is included.

Use the 'executable' flag to install a standalone executable, 'texmath', that
by default reads a LaTeX formula from 'stdin' and writes MathML to 'stdout'.
With flags all the functionality exposed by 'Text.TeXMath' can be accessed
through this executable. (Use the '--help' flag for a description of all
functionality)

The 'texmath' executable can also be used as a CGI script, when renamed as
'texmath-cgi'. It will expect query parameters for 'from', 'to', 'input', and
optionally 'inline', and return a JSON object with either 'error' and a message
or 'success' and the converted result.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup

%build
%define cabal_configure_options -fexecutable
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc README.markdown changelog
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc README.markdown changelog

%changelog
* Thu May 13 2021 psimons@suse.com
- Update texmath to version 0.12.3.
  texmath (0.12.3)
  * TeX reader: implement logic to convert a Bin symbol to
    an Op to Op when it occurs at the beginning of a group,
    or after an Open, Pun, or Op symbol. This will give much
    better results for unary `-` (#176).
  * OMML writer: fixed rendering of EDelimited (#173).
    We now properly render "middles" (separators).
* Tue Mar 16 2021 psimons@suse.com
- Update texmath to version 0.12.2.
  texmath (0.12.2)
  * MathML input: support mmultiscripts element (#158, #100).
  * Make MathML tag/attr recognition case-insensitive (#158).
  * Pandoc writer: better handling of styling such as `\mathrm` (#145).
    Previously identifiers were always italic, no matter what
    styling was applied.
  * Ignore `\tag` in TeX input (#162).
  * TeX writer: avoid unneeded `\left` and `\right` for delimited.
    We don't need `\left` and `\right` when the contents are
    "standard height."
  * TeX reader: parse implicit EDelimited sections (#172).
    We now parse `(x)` as EDelimited, even though `\right` and `\left`
    are not used.
* Mon Feb  8 2021 psimons@suse.com
- Update texmath to version 0.12.1.1.
  texmath (0.12.1.1)
  * Fix compilation with GHC-9.0.1 (#169, Simon Jakobi).
    Background:
    https://gitlab.haskell.org/ghc/ghc/-/wikis/migration/9.0#simplified-subsumption
  * Add eqn to online demo.
  * Improve error messages for unknown control sequences, and restructure
    tex parser to be more efficient (#167).
* Tue Dec 29 2020 psimons@suse.com
- Update texmath to version 0.12.1.
  texmath (0.12.1)
  * OMML writer: explicitly mark symbols as non-italic (#109).
    Otherwise, for some reason, they appear as italic by default.
  * Improve error messages in reading tex arrays.
  * Improve support for `\bmod`, `\mod`, etc. (#165).
    Allow them to take complex arguments like `\left( 1 \right)`.
  * Improve support for `\genfrac` (#164).
  * Ignore `\textstyle`, `\scriptstyle`, `\scriptscriptstyle`,
    as we currently ignore `\displaystyle`.
  * Parse siunitx commands in reading tex (#157).
  * Improve handling of `\not` in reading tex (#161).
    Previously we only handled `\not` in front of certain symbols.
  * Support `\pod` and `\pmod` and clean up spacing and font for
    `\mod` and `\bmod` (#160).
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Sep 22 2020 psimons@suse.com
- Update texmath to version 0.12.0.3.
  texmath (0.12.0.3)
  * Allow pandoc-types 1.22.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jul 21 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC avoid "no space left on device" build error
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update texmath to version 0.12.0.2.
  texmath (0.12.0.2)
  * Allow pandoc-types 1.21.
  * Pandoc output: omit empty Emph for sub/superscript without base (#155).
  * tex writer: Use `\overline{\overline{B}}` instead of unicode
    double line accent (#153).
* Thu Feb 27 2020 psimons@suse.com
- Update texmath to version 0.12.0.1.
  texmath (0.12.0.1)
  * OMML writer: Fix overline and accent rendering (#152).
  * OMML reader: Fix dropped arrows (#153). Add tests.
* Wed Nov 13 2019 psimons@suse.com
- Update texmath to version 0.12.
  texmath (0.12)
  * Use Text instead of String in data types and functions
    (Christian Despres) [API change].  Note that there are still a few
    places where we unpack Text to String with a view pattern:
    performance could likely be increased with further rewriting.
  * Avoid use of !! with negative index (jgm/pandoc#5853).
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct  5 2019 psimons@suse.com
- Update texmath to version 0.11.3.
  texmath (0.11.3)
  * Use error instead of fail to allow building with ghc 8.8.
  * Test output: remove superfluous spaces after control sequences,
    superfluous groups, and unicode VARIATION SELECTOR 1.
  * renderTeX: add space between control sequence and any non-ASCII
    character.  There are differences in behavior of isAlphaNum between
    different ghc versions that would affect test output otherwise.
  * charToLaTeXString: Ignore 65024 VARIATION SELECTOR 1 to avoid putting
    it literally in the output ; it is used in mathml output and occurs
    in many of the test cases.
  * Add cabal.project.
  * Use actions rather than travis for CI.
* Wed Sep 25 2019 psimons@suse.com
- Update texmath to version 0.11.2.3.
  texmath (0.11.2.3)
  * OMML reader: properly distinguish normal text from math (#136).
    If `m:nor` or `m:lit` is set in `m:rPr`, we interpret the
    contents as literal text and not as math.
  * TeX reader: use different symbol (`_`) for `\underline` (#142).
    This gets the right accent properties on MathML output, so
    that the underline is not lower than it should be.
  * TeX reader: Treat `\bmod` as a relational symbol rather than
    an operator (#143).  This fixes spacing problems in several
    output formats.
* Sat Mar  9 2019 psimons@suse.com
- Update texmath to version 0.11.2.2.
  texmath (0.11.2.2)
  * OMML writer: use m:nor for normal text (#135).
* Sun Mar  3 2019 psimons@suse.com
- Update texmath to version 0.11.2.1.
  texmath (0.11.2.1)
  * OMML reader: Don't collapse `fName` to a string (#133).
    This fixes cases where fName has some complexity, e.g.
    a subscript or limit.
* Fri Feb  1 2019 psimons@suse.com
- Update texmath to version 0.11.2.
  texmath (0.11.2)
  * Improved handling of \mathop etc (#126).  We now allow operators like
    `arg\,min`, converting the space into unicode.
  * Support \hspace (#126).
  * Support \hdots as synonym of \ldots (#126).
  * Support \mathds (#126).
  * In parsing array, ignore `|` in column specs (#127).
    We have no way to represent this in EArray, currently.
    Ignoring them seems better than failing altogether.
* Mon Oct 29 2018 psimons@suse.com
- Update texmath to version 0.11.1.2.
  texmath (0.11.1.2)
  * Eqn writer: properly escape `{` and `}`.
  * Set more accurate bounds (Herbert Valerio Riedel).
* Thu Oct  4 2018 psimons@suse.com
- Update texmath to version 0.11.1.1.
  texmath (0.11.1.1)
  * Fix building with ghc-8.6.1 by removing need for now missing
    MonadFail instances (Jonas Scholl).
  * TeX reader: Allow operators like `/` to be scaled (#120).
  * TeX reader: Improved efficiency of basicEnclosure.
  * TeX reader: Handle `\bmod` (#115).
  texmath (0.11.1)
  * OMML writer: Use m:acc for accents in OMML (#119).  This fixes
    some spacing issues for e.g. the translation of `\dot{m}`.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update texmath to version 0.11.0.1.
  texmath (0.11.0.1)
  * OMML writer: use zero-width space to avoid dashed box (#118).
    In Word, a dashed box shows up for empty text runs in
    exponents and bases, or empty exponents and bases.  So
    we use a zero-width space in these contexts.
* Mon May 14 2018 psimons@suse.com
- Update texmath to version 0.11.
  * Changed treatment of non-ASCII characters.
    Previously we ensured that the output of conversion to tex
    was pure ASCII.  This meant rendering "ä" as "a", for
    example, and it meant that many characters (e.g. Chinese)
    simply got replaced with an empty string, while others
    got replaced with "[?]".
    This was not a particularly helpful behavior.  Including
    the unicode characters verbatim doesn't interfere with
    latex compilation.  They often won't show up in the generated
    math, but that is no worse than what happened before.
    This change passes through unicode characters unchanged
    when they can't be converted to standard LaTeX commands.
    An important reason for including the unicode characters
    is that pandoc uses TeX to represent math in its AST.
    So, for example, if you convert HTML with mathml to docx,
    you'll currently lose all Chinese characters, since they'll
    disappear in the TeX intermediary, even though a direct
    mathml to ooml conversion would have passed them through.
    With this change, these conversions will work better
    (see jgm/pandoc#4642).
    + Removed Text.TeXMath.Unicode.ToASCII (API change).
    + Removed cbits that were needed for that module.
    + Modified Tex.TeXMath.Unicode.ToTeX to pass through
    unicode characters that can't be converted, rather
    than trying to asciify them or remove them.
  * Render degree symbol in tex as `{^\circ}`.
  * eqn writer:  use uppercase letters in unicode escapes (jgm/pandoc#4597).
  * Handle multicharacter operators better in Eqn, TeX, OMML (#109).
  * OMML reader: unwrap `<w:...>` tags immediately under `<m:oMath>`
    (#111, Jesse Rosenthal).
  * Expose Text.TeXMath.TeX (TeX rendering functions) (#108).
    This is needed in order to use getTeXMath from Text.TeXMath.Unicode.ToTeX.
  * Pandoc writer: don't insert punctuation space before explicit space
    (#107).  E.g. in `2,\!4`.
  * Fix end-line command ('\\') in AMSmath environments (ARATA Mizuki).
    The end-line command in AMSmath environments does not allow spaces
    before its optional argument.
  * Use `\in` for SMALL ELEMENT OF in "base" (Vaclav Haisman).
  * Use `\ni` in base for U+220D (#103).
  * Improved unicode -> tex symbol lookup.  Previously we had many
    cases where the lookup table would map a unicode character to
    the empty string for the base package, and this would print finding
    a good match in another package in the environment.
  * Added support for `\symbf` (#101).
  * Revert "migrating the lookup structures for Unicode/ToTex.hs to
    use C source files to accelerate builds."  This change gave us somewhat
    faster builds (using less memory), but at a huge cost of
    maintainability.
  * Removed AlignDefault from Alignment (API change, #102).
    AlignDefault doesn't make sense for a converter between
    formats that may have different defaults.  We now properly treat
    centering as the default in MathML and OMML input.
  * Update tests that should have been updated for 0.9.4.3.
  * MathML writer: put linethickness attribute directly on mfrac
    element. This fixes binomial rendering.
  * Pandoc writer: better handle accented characters (jgm/pandoc#3922).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Jul 11 2017 psimons@suse.com
- Update to version 0.9.4.1.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.9.4 with cabal2obs.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.9.3 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.9.1 with cabal2obs.
* Sun Oct 30 2016 psimons@suse.com
- Update to version 0.8.6.7 with cabal2obs.
* Mon Oct 17 2016 psimons@suse.com
- Update to version 0.8.6.6 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.8.6.5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.6.4 revision 0 with cabal2obs.
* Tue Jun 28 2016 mimi.vx@gmail.com
- regenerate spec-file, fix ghc-texmath-devel requires
- remove texmath-rpmlintrc
* Mon Jun 27 2016 mimi.vx@gmail.com
- update to 0.8.6.4
  * Handle equation environment (without numbering).
* Thu May 26 2016 mimi.vx@gmail.com
- update to 0.8.6.3
  * Use POST instead of GET for texmath-cgi.
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 0.8.6.2
  * Fixed array alignment issues
  * Use 1 and 0 for _Hide attributes, rather than on and off.
  * Fixed EUnderOver for omml output.  Previously both the under and
    the over part were being placed under
* Thu Mar 31 2016 mimi.vx@gmail.com
- update to 0.8.6.1
  * OMML writer:  Fixed rendering of roots, so that the degree appears
    in the right place.
  * OMML writer:  Don't include empty rPr elements.
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 0.8.6
  * TeX reader: Support hundreds more math symbols (all of those defined in
    Text.TeXMath.Unicode.ToTeX), including `\nwarrow`, `\swarrow`, `\nearrow`,
    `\searrow`.
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 0.8.5.1
  * OMML writer: Fixed order of elements in nary formulas to conform
    to OMML spec (#88, Niko Weh).  `<e>` must follow the `<sup>` and `<sub>`
    parts of `<nary>`. This fixes rendering issues in LibreOffice
    (though Word copes with the incorrect order).
  * Added Paths_texmath to Other-Modules for texmath executable.
* Mon Mar 21 2016 mimi.vx@gmail.com
- update to 0.8.5
  * TeX parser: Support limited styling inside \DeclareMathOperator.
  * TeX reader: Correctly parse \mbox.  Its argument is text mode.
  * Updated mathml tests to use mo for operators.
  * TeX reader: support mathopen, mathclose, mathpunct.
  * MathML writer: render EMathOperator as mo, not mi.
  * MathML: handle leading space in EText.
  * Take --version in executable from cabal metadata.
  * Added Paths_texmath to other-modules.
* Sun Feb 14 2016 mimi.vx@gmail.com
- update to 0.8.4.2
  * Fixed overbrace, underbrace.  Previously we were using the wrong
    character: U+FE37 instead of U+23DE.  This didn't work in Word.
  * Support \mathop, \mathrel, \mathbin, \mathord
  * MathML - render Symbol Ord as mi, not mo.
  * Handle align environments with > 2 cells per row.
* Sun Dec 13 2015 mimi.vx@gmail.com
- update to 0.8.4.1
  * Fixed bold-italic in OMML.  Previously `\mathbfit` didn't work
    properly in OMML output.
  * Ignore `\nonumber`.
  * Allow styling in `\operatorname` e.g. `\operatorname{\mathcal{L}}`.
  * Fixed bug in `supHide` and `subHide` for OMML.  This  led to little
    empty boxes being displayed in integrals with subscripts but no
    superscripts.
  * Implemented `\mod` as a math operator.  This doesn't capture all the
    spacing subtleties of the amsmath version, but should be good enough
    for most purposes.
  * Allow pandoc-types < 1.17.
  * Improved symbol spacing in Pandoc output.
    This change avoids putting space around binary symbols that
    come at the beginning or end of a group, or appear on their
    own.  It also avoids spacing on a binary symbol that follows
    a Bin, Op, Rel, Open, or Punct atom, in accord with
    TeXBook Appendix G.  We could go farther towards exactly
    matching the TeXBook rules, but this simple change goes some of
    the way.
* Sun Oct 18 2015 mimi.vx@gmail.com
- update to 0.8.4
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 0.8.3
  * Parse uppercase Greek letters as EIdentifier, not ESymbol Op.
  This fixes handling of things like `$Lambda^1$`, particularly in omml.
* Mon Jul  6 2015 mimi.vx@gmail.com
- update to 0.8.2.2
  * Handle . after number with no following digits.
  * Handle bare hyphen in \text{...}. Closes jgm/pandoc#2274.
  * Support \ltimes and \rtimes in the TeX reader (Arata Mizuki).
  * Slightly more efficient number parser.
* Mon May  4 2015 mimi.vx@gmail.com
- update to 0.8.2
  * Better handling of decimal points. Decimal points are now parsed
    as parts of numbers, not as separate symbols.  E.g. in MathML they
    now appear in `<mn>` elements.  Closes #74.
* Thu Apr 23 2015 mimi.vx@gmail.com
- update to 0.8.1
  * OMML: Don't force everything into Roman font by default.
    This change ensures that variables will be italic by
    default in Word.  See jgm/pandoc#2075.
  * Fixed typo in `defaultEnv` to include `amssymb` (#68).
  * Moved some lookup tables to C, and disabled aggressive
    profiling defaults, to avoid excessive memory usage in
    compiling with clang (#70).
  * Support `\newcommand*` in `parseMacroDefinition` (jgm/pandoc#2005).
  * Fixed order bug for over/under in OMML reader (#66).
  * Support `\boldsymbol` (#67).
  * Added network-uri flag. This addresses the split of network
    and network-uri packages.
  * OMML reader: change default accent (Jesse Rosenthal).
    The default had previously been set as accute (possibly as a
    placeholder). It appears to be circumflex/hat instead.
  * Added OMML reader (Jesse Rosenthal).
  * Support latex \substack (#57).
  * Added EBoxed and implemented in readers and writers (#58).
  * Handle latex \genfrac.  Use \genfrac for \brace, \brack,
    etc. when amsmath is available.
  * Improvements in handling of space characters.
  * Use ESpace rather than EText when a mathml mtext just contains
    a space.
  * Use \mspace when needed to get latex spaces with odd sizes, rather
    than finding the closest simple command.
  * Use Rational instead of Double in ESpaced, EScaled.
  * Shared: Export getSpaceWidth, getSpaceChars.
  * Shared: Export fixTree, isEmpty, empty (formerly in MathML reader).
  * TeX reader:  further improvements in error reporting.
    Instead of reporting line and column, a snippet is printed
    with a caret indicating the position of the error.  Also
    fixed bad position information when control sequences are
    followed by a letter.
  * TeX reader:
    + Improved error reporting.
    + Optimized parser.
    + Treat `\ ` as ESpaced rather than ESymbol.
    + Internal improvements, including using the parsec3 interface
    instead of the older parsec2 compatibility interface.
  * Added tests for phantom.
  * Changes in Exp type:
    + Removed EUp, EDown, EDownup, EUnary, EBinary.
    + Added EFraction (and FractionType), ESqrt, Eroot, EPhantom.
    + Added boolean "convertible" parameter to EUnder, EOver, EUnderover.
    + Changed parameter of EScaled from String to Double.
    + Changed parameter of ESpace from String to Double.
    + Removed EStretchy.
    + Added EStyled, corresponding to mstyle in mathml, and \mathrm,
    \mathcal, etc. in TeX (which can contain arbitrary math content,
    not just text).
    + Changed the type of EDelimited.  The contents of an EDelimited are
    now either Right Exp or Left String (the latter case represents a
    fence in middle position, e.g. \mid| in LaTeX).
  * Module reorganisation:  the exposed interface has been completely
    changed, and modules for reading MathML and writing TeX math
    have been added:
    + All writers now reside in Text.TeXMath.Writers.
  - Text.TeXMath.MathML -> Text.TeXMath.Writers.MathML.
    toMathML and showExp are removed, writeMathML added.
  - Text.TeXMath.OMML -> Text.TeXMath.Writers.OMML.
    toOMML and showExp removed, writeOMML added.
  - Text.TeXMath.Pandoc -> Text.TeXMath.Writers.Pandoc.
    toPandoc removed, writePandoc added.
  - New module Text.TeXMath.Writers.TeX, exporting writeTeX,
    writeTeXWith, addLaTeXEnvironment (the latter giving control
    over which packages are assumed to be available).
    + All readers now reside in Text.TeXMath.Readers.
  - Text.TeXMath.MathMLParser -> Text.TeXMath.Readers.MathML,
    exporting readMathML.
  - Text.TeXMath.Readers.TeX nows exports readTeX rather than
    parseFormula.
    + New modules for unicode conversion: Text.TeXMath.Unicode.ToASCII,
    Text.TeXMath.Unicode.ToTeX, Text.TeXMath.Unicode.ToUnicode.
    + Two MathML specific modules: Text.TeXMath.Readers.MathML.EntityMap,
    Text.TeXMath.Readers.MathML.MMLDict.
    + In Text.TeXMath, all the XtoY functions have been removed
    in favour of rexporting raw reader and writer functions. The
    data type Exp is now also exported.
    + TeX writer: Properly handle accents inside \text{}.
    Use real text environments for EText (\textrm, not \mathrm).
    Improved handling of scalers (\Big etc.).  Use amsmath matrix
    environments when appropriate.  Fixed \varepsilon.
    + MathML writer:  Omit superfluous outer mrows.  Add position
    information to fences.
    + OMML writer:  Handle \phantom.
    + Pandoc writer:  Use unicode characters to support Fraktur and
    other text styles.
    + TeX reader:  Use EUnder/Over for \stackrel, \overset, \underset.
    Improved handling of primes.  Fixed \notin.  Avoid superfluous
    grouping of single elements.  Improved handling of scalers (\Big etc.).
    Handle \choose, \brace, \brack, \bangle (#21).
    + Macros:  Don't raise an error if applying a macro fails to
    resolve to a fixed point; instead, just return the original string.
  * Rewrote test suite as a proper cabal test suite.  Added
  - -regenerate-tests and --round-trip options.
  * Removed cgi and test flags.  Added executable flag to build texmath.
  * Modified texmath so it works like a cgi script when run as
    texmath-cgi (through symlink or renaming).  Removed dependency on
    the cgi package.
  * New Module: Text.TeXMath.Unidecode, a module for approximating
    unicode characters in ASCII.
  * New Module: Text.TeXMath.Shared, a module for shared lookup
    tables between the various readers and writers
  * New Module: Text.TeXMath.MathMLParser, exporting readMathML.
  * New Module: Text.TeXMath.EntityMap, exporting getUnicode,
    a conversion table from MathML entities to unicode characters.
  * New Module: Text.TeXMath.UnicodeToLaTeX, exporting getLaTeX,
    converting a string of unicode characters to a string of equivalent LaTeX
    commands.
  * New Module: Text.TeXMath.LaTeX, replacing Text.TeXMath.Parser,
    exporting toTeXMath.
  * New Module: Text.TeXMath.MMLDict, implements a lookup table from
    operators to their default values as defined by the MML dictionary,
    exporting getOperator.
  * New Module: Text.TeXMath.Compat, maintaining compatibility with
    mtl < 2.2.1.
  * Modified Text.TeXMath to export the primitive readers, as well as
    mathMLTo{Writer} for all writers
  * Modified: Text.TeXMath.Types: added additional record types for
    Text.TeXMath.MMLDict and Text.TeXMath.UnicodeToLaTeX.
    New Exports: Operator(..), Record(..).
  * Modified test suite:  use cabal test, added significant number of tests.
  * Added recognition of the LaTeX command \phantom
  * Use combining tilde accent for \tilde.  Closes pandoc #1324.
  * Allow \left to be used with ), ], etc.  Ditto with \right.
    Previously only (, [, etc. were allowed with \left.  Closes pandoc #1319.
  * Support \multline (previously it was mispelled "multiline")
  * Changed data-files to extra-source-files.
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Thu Mar 27 2014 sbahling@suse.com
- Correct package License
* Sat Mar 15 2014 sbahling@suse.com
- update to 0.6.6
- needed for pandoc 1.12.3.3
  texmath changes:
  * Insert braces around macro expansions to prevent breakage (#7).
  * Support \operatorname and \DeclareMathOperator (rekka) (#17).
  * Support \providecommand (#15).
  * Fixed spacing bugs in pandoc rendering (#24).
  * Ignore \hline at end of array row instead of failing (#19).
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 0.6.5.2
- needed for pandoc 1.12.2.1
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- remove cgi support
  * not needed for pandoc
  * drop dependency on ghc-utf8-string-devel
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- merge d:l:haskell changes
* Sun Oct  6 2013 sbahling@suse.com
- update to 0.6.4
- Change Group from Development/Languages/Other to
  Productivity/Publishing/TeX/Utilities
* Thu May 16 2013 peter.trommler@ohm-hochschule.de
- update to 0.6.1.5 from upstream
  * fixed type face for math operators
  * fixed \overset, \underset, and \stackrel commands
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- update to 0.6.1.3 from upstream
  * gobble whitespace after formula as well as before.
  * fixed \dot and \ddot.
  * added \Upsilon
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.6.1.1 from upstream
  * fixes in unicode handling
  * fixes in various output formats (OMML, MML3, ...)
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Tue Mar 13 2012 peter.trommler@ohm-hochschule.de
- upgrade to 0.6.0.3 from upstream (for pandoc 1.9.1.2)
* Fri Jan 20 2012 herbert@graeber-clan.de
- downgrade to version 0.5.0.4 (pandoc needs this)
* Fri Jan 20 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
